@@ -1,6 +1,7 @@
+/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*parametros.h
 *
-*    Copyright (C) 2005 Rizoma Tecnologia Limitada <jonathan@rizoma.cl>
+*    Copyright (C) 2005 Rizoma Tecnologia Limitada <info@rizoma.cl>
 *
 *    This file is part of rizoma.
 *
@@ -16,13 +17,13 @@
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program; if not, write to the Free Software
-*    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+*    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
 #ifndef PARAMETROS_H
 
 #define PARAMETROS_H
 
-void Parametros (GtkWidget *main_box);
+void preferences_box ();
 
 #endif
